files

package
v0.0.0-...-2db02b6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 31, 2026 License: AGPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CountDirFiles

func CountDirFiles(dirName string) int

CountDirFiles counts the number of files in the specified directory. It returns the total count of files found in the directory.

func CreateDir

func CreateDir(path string) error

CreateDir creates a new directory at the specified path.

func FileMD5

func FileMD5(path string) (string, error)

FileMD5 calculates the MD5 hash of the file at the specified path.

func IsDir

func IsDir(path string) bool

IsDir checks if the specified path is a directory. It returns true if the path is a directory, false otherwise.

func IsExist

func IsExist(path string) bool

IsExist checks if the specified path exists. It returns true if the path exists, false otherwise.

func MkFileFullPathDir

func MkFileFullPathDir(fileName string) error

MkFileFullPathDir is used to file create the full path. eg. there is a file "./aa/bb/xxx.txt", and dir ./aa/bb is not exist, and will create the full path dir.

func Mkdir

func Mkdir(dirName string) error

Mkdir creates a directory named path, along with any necessary parents, and returns nil, or else returns an error.

func RemoveAll

func RemoveAll(path string) error

RemoveAll removes path and any children it contains.

func Untar

func Untar(src, dst string) error

Untar extracts the contents of a tar archive from the source file to the destination directory.

Types

This section is empty.

Jump to