Documentation
¶
Index ¶
- func CountDirFiles(dirName string) int
- func CreateDir(path string) error
- func FileMD5(path string) (string, error)
- func IsDir(path string) bool
- func IsExist(path string) bool
- func MkFileFullPathDir(fileName string) error
- func Mkdir(dirName string) error
- func RemoveAll(path string) error
- func Untar(src, dst string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CountDirFiles ¶
CountDirFiles counts the number of files in the specified directory. It returns the total count of files found in the directory.
func IsDir ¶
IsDir checks if the specified path is a directory. It returns true if the path is a directory, false otherwise.
func IsExist ¶
IsExist checks if the specified path exists. It returns true if the path exists, false otherwise.
func MkFileFullPathDir ¶
MkFileFullPathDir is used to file create the full path. eg. there is a file "./aa/bb/xxx.txt", and dir ./aa/bb is not exist, and will create the full path dir.
func Mkdir ¶
Mkdir creates a directory named path, along with any necessary parents, and returns nil, or else returns an error.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.